@@ -48,10 +48,7 @@
 #include "../include/struct.h"     /* typdef and struct declarations */
 #include "../include/prototype.h"  /* function prototypes */
 #include "../include/globals.h"
-
-#ifdef HAVE_LIBDMALLOC
-#include <dmalloc.h>
-#endif
+#include "../include/gettext.h"
 
 
 
@@ -123,7 +120,7 @@ void s_string_list_add_item(STRING_LIST *list, int *count, char *item) {
   STRING_LIST *local_list;
   
   if (list == NULL) {
-    fprintf(stderr, "In s_string_list_add_item, tried to add to a NULL list.\n");
+    fprintf(stderr, _("In s_string_list_add_item, tried to add to a NULL list.\n"));
     return;
   }
 
@@ -188,7 +185,7 @@ void s_string_list_delete_item(STRING_LIST **list, int *count, gchar *item) {
 
   /* First check to see if list is empty.  If empty, spew error and return */
   if ( (*list)->data == NULL) {
-    fprintf(stderr, "In s_string_list_delete_item, tried to remove item from empty list\n");
+    fprintf(stderr, _("In s_string_list_delete_item, tried to remove item from empty list\n"));
     return;
   }
 
@@ -252,7 +249,7 @@ void s_string_list_delete_item(STRING_LIST **list, int *count, gchar *item) {
   /* If we are here, it's 'cause we didn't find the item.
    * Spew error and return.
    */
-  fprintf(stderr, "In s_string_list_delete_item, couldn't delete item %s\n", item);
+  fprintf(stderr, _("In s_string_list_delete_item, couldn't delete item %s\n"), item);
   return;
 
 }
