@@ -54,11 +54,7 @@
 #include "../include/struct.h"     /* typdef and struct declarations */
 #include "../include/prototype.h"  /* function prototypes */
 #include "../include/globals.h"
-
-
-#ifdef HAVE_LIBDMALLOC
-#include <dmalloc.h>
-#endif
+#include "../include/gettext.h"
 
 static void show_entry(GtkWidget *widget, gpointer data);
 
@@ -71,31 +67,31 @@ void
 x_gtksheet_init()
 {
   gint i;
-  gchar *folder[]= {"Components",
-                   "Nets",
-                   "Pins"};
+  gchar *folder[]= {_("Components"),
+                   _("Nets"),
+                   _("Pins")};
 
 
   /* ---  Create three new sheets.   were malloc'ed in x_window_init  --- */
 
   /* -----  Components  ----- */
   if ((sheet_head->comp_count > 0) && (sheet_head->comp_attrib_count >0)) {
-    sheets[0] = (GtkSheet *) gtk_sheet_new((guint) sheet_head->comp_count, (guint) sheet_head->comp_attrib_count, "Components");
+    sheets[0] = (GtkSheet *) gtk_sheet_new((guint) sheet_head->comp_count, (guint) sheet_head->comp_attrib_count, _("Components"));
   } else {
-    x_dialog_fatal_error("No components found in design.  Please check your schematic and try again!\n", 1);
+    x_dialog_fatal_error(_("No components found in design.  Please check your schematic and try again!\n"), 1);
   }
   
 
 #ifdef UNIMPLEMENTED_FEATURES
   /* -----  Nets  ----- */
   if ((sheet_head->net_count > 0) && (sheet_head->net_attrib_count >0)) {
-    sheets[1] = (GtkSheet *) gtk_sheet_new(sheet_head->net_count, sheet_head->net_attrib_count, "Nets");
+    sheets[1] = (GtkSheet *) gtk_sheet_new(sheet_head->net_count, sheet_head->net_attrib_count, _("Nets"));
     gtk_sheet_set_locked(GTK_SHEET(sheets[1]), TRUE);   /* disallow editing of attribs for now */
   } else {
-    sheets[1] = (GtkSheet *) gtk_sheet_new(1, 1, "Nets");
-    gtk_sheet_row_button_add_label(sheets[1], 0, "TBD");
+    sheets[1] = (GtkSheet *) gtk_sheet_new(1, 1, _("Nets"));
+    gtk_sheet_row_button_add_label(sheets[1], 0, _("TBD"));
     gtk_sheet_row_button_justify(sheets[1], 0, GTK_JUSTIFY_LEFT);
-    gtk_sheet_column_button_add_label(sheets[1], 0, "TBD");
+    gtk_sheet_column_button_add_label(sheets[1], 0, _("TBD"));
     gtk_sheet_column_button_justify(sheets[1], 0, GTK_JUSTIFY_LEFT);
     gtk_sheet_set_locked(GTK_SHEET(sheets[1]), TRUE);   /* disallow editing of attribs for now */
   }
@@ -105,10 +101,10 @@ x_gtksheet_init()
 #ifdef UNIMPLEMENTED_FEATURES
   /* -----  Pins  ----- */
   if ((sheet_head->pin_count > 0) && (sheet_head->pin_attrib_count >0)) {
-    sheets[2] = (GtkSheet *) gtk_sheet_new(sheet_head->pin_count, sheet_head->pin_attrib_count, "Pins");
+    sheets[2] = (GtkSheet *) gtk_sheet_new(sheet_head->pin_count, sheet_head->pin_attrib_count, _("Pins"));
     gtk_sheet_set_locked(GTK_SHEET(sheets[2]), TRUE);   /* disallow editing of attribs for now */
   } else {
-    sheets[2] = (GtkSheet *) gtk_sheet_new(1, 1, "Pins");
+    sheets[2] = (GtkSheet *) gtk_sheet_new(1, 1, _("Pins"));
     gtk_sheet_set_locked(GTK_SHEET(sheets[2]), TRUE);    /* disallow editing of attribs for now */
   }
 #endif
@@ -146,8 +142,8 @@ x_gtksheet_init()
       /*  Note that the entry cell is the text entry field at the top of the
        *  sheet's working area (like in MS E*cel).   I have removed this from
        *  gattrib, but leave the code in just in case I want to put it back.  */
-      gtk_signal_connect(GTK_OBJECT(gtk_sheet_get_entry(GTK_SHEET(sheets[i]))),
-			   "changed", (GtkSignalFunc) show_entry, NULL);
+      g_signal_connect (gtk_sheet_get_entry (GTK_SHEET (sheets[i])),
+                        "changed", (GCallback) show_entry, NULL);
     }
   }
 }
@@ -356,7 +352,7 @@ void x_gtksheet_set_cell_text_color(GtkSheet *sheet, gint row, gint col,
   }
 
   if (!gdk_colormap_alloc_color (cmap, color, FALSE, FALSE)) {
-    g_error ("couldn't allocate color");
+    g_error (_("couldn't allocate color"));
     return;
   }
   /*   g_free(cmap); */
