@@ -2,7 +2,7 @@
  * gEDA - GPL Electronic Design Automation
  * gschem - gEDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2019 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2020 gEDA Contributors (see ChangeLog for details)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 extern GList *global_window_list;
 
 /* Manager for recently used files */
-GtkRecentManager *recent_manager;
+extern GtkRecentManager *recent_manager;
 
 /* colors */
 extern GdkColor white;
