@@ -102,7 +102,6 @@ void g_init_window ();
 /* gschem.c */
 typedef void (*gschem_atexit_func)(gpointer data);
 void gschem_atexit(gschem_atexit_func func, gpointer data);
-void gschem_quit(void);
 void main_prog(void *closure, int argc, char *argv[]);
 int main(int argc, char *argv[]);
 /* i_basic.c */
@@ -281,7 +280,7 @@ void o_pin_draw_rubber(GschemToplevel *w_current, EdaRenderer *renderer);
 void o_pin_invalidate_rubber(GschemToplevel *w_current);
 /* o_place.c */
 void o_place_start(GschemToplevel *w_current, int x, int y);
-void o_place_end(GschemToplevel *w_current, int x, int y, int continue_placing, const char *hook_name, const gchar *undo_desc);
+void o_place_end(GschemToplevel *w_current, int x, int y, int continue_placing, int select_placed, const char *hook_name, const gchar *undo_desc);
 void o_place_motion(GschemToplevel *w_current, int x, int y);
 void o_place_invalidate_rubber(GschemToplevel *w_current, int drawing);
 void o_place_draw_rubber(GschemToplevel *w_current, EdaRenderer *renderer);
@@ -343,7 +342,7 @@ void x_basic_warp_cursor(GtkWidget *widget, gint x, gint y);
 /* x_clipboard.c */
 void x_clipboard_init (GschemToplevel *w_current);
 void x_clipboard_finish (GschemToplevel *w_current);
-void x_clipboard_query_usable (GschemToplevel *w_current, void (*callback) (int, void *), void *userdata);
+void x_clipboard_update_menus (GschemToplevel *w_current);
 gboolean x_clipboard_set (GschemToplevel *w_current, const GList *object_list);
 GList *x_clipboard_get (GschemToplevel *w_current);
 /* x_color.c */
@@ -399,10 +398,9 @@ gboolean x_event_get_pointer_position (GschemToplevel *w_current, gboolean snapp
 void x_compselect_deselect (GschemToplevel *w_current);
 void x_compselect_select_previous_symbol (GschemToplevel *w_current);
 /* x_fam.c */
-enum FAMCodes;
 void x_fam_init (void);
 void x_fam_free (void);
-gpointer x_fam_monitor (const gchar *path, void (*exists_event) (const gchar *path, enum FAMCodes code, gpointer user_data), void (*regular_event) (const gchar *path, enum FAMCodes code, gpointer user_data), gpointer user_data);
+gpointer x_fam_monitor (const gchar *path, void (*exists_event) (const gchar *path, unsigned int code, gpointer user_data), void (*regular_event) (const gchar *path, unsigned int code, gpointer user_data), gpointer user_data);
 void x_fam_unmonitor (gpointer handle);
 /* x_fileselect.c */
 PAGE *x_fileselect_create (GschemToplevel *w_current, const gchar *dirname, const gchar *basename);
