@@ -1,7 +1,7 @@
 /* gEDA - GPL Electronic Design Automation
  * gschem - gEDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2019 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2020 gEDA Contributors (see ChangeLog for details)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -752,7 +752,12 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
   CONN *found_conn = NULL;
   int done;
   int otherone;
-  BUS_RIPPER rippers[2];
+  struct {
+    int x[2];
+    int y[2];
+    int angle;
+    int mirror;
+  } rippers[2];
   int ripper_count = 0;
   int i;
   double length;
@@ -761,7 +766,6 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
   int first, second;
   int made_changes = FALSE;
   const int ripper_size = w_current->bus_ripper_size;
-  int complex_angle = 0;
   const CLibSymbol *rippersym = NULL;
 
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
@@ -852,17 +856,9 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
             break;
           }
 
-          if (w_current->bus_ripper_rotation == NON_SYMMETRIC) {
-            /* non-symmetric */
-            if (sign == 1) {
-              complex_angle = 0;
-            } else {
-              complex_angle = 90;
-            }
-          } else {
-            /* symmetric */
-            complex_angle = 0;
-          }
+          /* up, right/left */
+          rippers[ripper_count].angle = 0;
+          rippers[ripper_count].mirror = sign == 1 ? 0 : 1;
 
           net_obj->line->y[found_conn->whichone] -= ripper_size;
           net_obj->w_bounds_valid_for = NULL;
@@ -889,17 +885,9 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
             break;
           }
 
-          if (w_current->bus_ripper_rotation == NON_SYMMETRIC) {
-            /* non-symmetric */
-            if (sign == 1) {
-              complex_angle = 270;
-            } else {
-              complex_angle = 180;
-            }
-          } else {
-            /* symmetric */
-            complex_angle = 180;
-          }
+          /* down, right/left */
+          rippers[ripper_count].angle = 180;
+          rippers[ripper_count].mirror = sign == 1 ? 1 : 0;
 
           net_obj->line->y[found_conn->whichone] += ripper_size;
           net_obj->w_bounds_valid_for = NULL;
@@ -960,17 +948,9 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
             break;
           }
 
-          if (w_current->bus_ripper_rotation == NON_SYMMETRIC) {
-            /* non-symmetric */
-            if (sign == 1) {
-              complex_angle = 0;
-            } else {
-              complex_angle = 270;
-            }
-          } else {
-            /* symmetric */
-            complex_angle = 270;
-          }
+          /* right, up/down */
+          rippers[ripper_count].angle = 270;
+          rippers[ripper_count].mirror = sign == 1 ? 1 : 0;
 
           net_obj->line->x[found_conn->whichone] -= ripper_size;
           net_obj->w_bounds_valid_for = NULL;
@@ -996,17 +976,9 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
             break;
           }
 
-          if (w_current->bus_ripper_rotation == NON_SYMMETRIC) {
-            /* non-symmetric */
-            if (sign == 1) {
-              complex_angle = 90;
-            } else {
-              complex_angle = 180;
-            }
-          } else {
-            /* symmetric */
-            complex_angle = 90;
-          }
+          /* left, up/down */
+          rippers[ripper_count].angle = 90;
+          rippers[ripper_count].mirror = sign == 1 ? 0 : 1;
 
           net_obj->line->x[found_conn->whichone] += ripper_size;
           net_obj->w_bounds_valid_for = NULL;
@@ -1052,7 +1024,7 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
         if (rippersym != NULL) {
           new_obj = o_complex_new (page->toplevel, OBJ_COMPLEX, DEFAULT_COLOR,
                                    rippers[i].x[0], rippers[i].y[0],
-                                   complex_angle, 0,
+                                   rippers[i].angle, rippers[i].mirror,
                                    rippersym,
                                    page->toplevel->bus_ripper_symname, 1);
           s_page_append_list (page->toplevel, page,
