@@ -2,10 +2,8 @@
 extern int default_init_right;
 extern int default_init_bottom;
 
-extern char *default_untitled_name;
 extern char *default_bitmap_directory;
 extern char *default_bus_ripper_symname;
-extern char *default_postscript_prolog;
 
 extern GList *default_always_promote_attributes;
 
