@@ -1,6 +1,6 @@
 /* gEDA - GPL Electronic Design Automation
  * libgeda - gEDA's Library
- * Copyright (C) 2011-2019 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 2011-2020 gEDA Contributors (see ChangeLog for details)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,7 +77,7 @@ static void parent_config_changed_handler (EdaConfig *parent, const gchar *group
 static void propagate_key_file_error (GError *src, GError **dest);
 
 /*! Magic helpful GObject macro */
-G_DEFINE_TYPE (EdaConfig, eda_config, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (EdaConfig, eda_config, G_TYPE_OBJECT)
 
 /*! Initialise EdaConfig class. */
 static void
@@ -86,8 +86,6 @@ eda_config_class_init (EdaConfigClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GParamSpec *pspec;
 
-  g_type_class_add_private (gobject_class, sizeof (EdaConfigPrivate));
-
   /* Register functions with base class */
   gobject_class->dispose = eda_config_dispose;
   gobject_class->finalize = eda_config_finalize;
@@ -141,9 +139,7 @@ eda_config_class_init (EdaConfigClass *klass)
 static void
 eda_config_init (EdaConfig *config)
 {
-  config->priv = G_TYPE_INSTANCE_GET_PRIVATE (config,
-                                              EDA_TYPE_CONFIG,
-                                              EdaConfigPrivate);
+  config->priv = eda_config_get_instance_private (config);
 
   config->priv->parent = NULL;
   config->priv->keyfile = g_key_file_new ();
@@ -525,15 +521,17 @@ eda_config_get_context_for_file (GFile *path)
     g_once_init_leave (&initialized, 1);
   }
 
-  if (path == NULL) {
+  if (path != NULL) {
+    g_return_val_if_fail (G_IS_FILE (path), NULL);
+
+    /* Find the project root, and the corresponding configuration
+     * filename. */
+    root = find_project_root (path);
+  } else {
     path = g_file_new_for_path (".");
+    root = find_project_root (path);
+    g_object_unref (path);
   }
-
-  g_return_val_if_fail (G_IS_FILE (path), NULL);
-
-  /* Find the project root, and the corresponding configuration
-   * filename. */
-  root = find_project_root (path);
   file = g_file_get_child (root, LOCAL_CONFIG_NAME);
 
   /* If there's already a context available for this file, return
